@@ -192,12 +192,14 @@ public class EPPUtil {
 					retBigDecimal = new BigDecimal(tempDouble.doubleValue());
 					retBigDecimal = retBigDecimal.setScale(2,
 							BigDecimal.ROUND_HALF_UP);
-				} catch (NumberFormatException e) {
+				}
+				catch (NumberFormatException e) {
 					throw new EPPDecodeException(
 							"Can't convert value to Double: " + doubleValStr
 									+ e);
 				}
-			} else {
+			}
+			else {
 				throw new EPPDecodeException(
 						"Can't decode numeric value from non-existant text node");
 			}
@@ -242,10 +244,12 @@ public class EPPUtil {
 
 				if (theVal.equalsIgnoreCase("true") || theVal.equals("1")) {
 					retVal = new Boolean(true);
-				} else {
+				}
+				else {
 					retVal = new Boolean(false);
 				}
-			} else {
+			}
+			else {
 				retVal = null;
 			}
 		}
@@ -281,9 +285,11 @@ public class EPPUtil {
 
 		if (theAttrVal.equals("1") || theAttrVal.equals("true")) {
 			theRet = true;
-		} else if (theAttrVal.equals("0") || theAttrVal.equals("false")) {
+		}
+		else if (theAttrVal.equals("0") || theAttrVal.equals("false")) {
 			theRet = false;
-		} else {
+		}
+		else {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeBooleanAttr: Invalid boolean attr " + aAttr
 							+ " value of " + theAttrVal);
@@ -292,7 +298,29 @@ public class EPPUtil {
 		return theRet;
 	}
 
-	// End EPPUtil.decodeTimeInstant(String)
+	/**
+	 * Decodes a string attribute by name. If the attribute is not found,
+	 * <code>null</code> is returned.
+	 * 
+	 * @param aElement
+	 *            Element to search for the attribute
+	 * @param aAttr
+	 *            Attribute name to search for
+	 * @return Attribute <code>String</code> value if exists; <code>null</code>
+	 *         otherwise.
+	 */
+	public static String decodeStringAttr(Element aElement, String aAttr) {
+		String theRet = null;
+
+		String theAttrVal = aElement.getAttribute(aAttr);
+
+		if (theAttrVal != null && !theAttrVal.isEmpty()) {
+			theRet = theAttrVal;
+		}
+
+		return theRet;
+
+	}
 
 	/**
 	 * Decode a <code>EPPCodecComponent</code>, by XML namespace and tag name,
@@ -332,10 +360,12 @@ public class EPPUtil {
 
 				retVal.decode(theElm);
 			}
-		} catch (IllegalAccessException e) {
+		}
+		catch (IllegalAccessException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeComp(), IllegalAccessException: " + e);
-		} catch (InstantiationException e) {
+		}
+		catch (InstantiationException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeComp(), InstantiationException: " + e);
 		}
@@ -389,10 +419,12 @@ public class EPPUtil {
 			}
 
 			// end for each element
-		} catch (IllegalAccessException e) {
+		}
+		catch (IllegalAccessException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeCompList(), IllegalAccessException: " + e);
-		} catch (InstantiationException e) {
+		}
+		catch (InstantiationException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeCompList(), InstantiationException: " + e);
 		}
@@ -446,10 +478,12 @@ public class EPPUtil {
 			}
 
 			// end for each element
-		} catch (IllegalAccessException e) {
+		}
+		catch (IllegalAccessException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeCompVector(), IllegalAccessException: " + e);
-		} catch (InstantiationException e) {
+		}
+		catch (InstantiationException e) {
 			throw new EPPDecodeException(
 					"EPPUtil.decodeCompVector(), InstantiationException: " + e);
 		}
@@ -553,12 +587,14 @@ public class EPPUtil {
 				String intValStr = textNode.getNodeValue();
 				try {
 					retInteger = Integer.valueOf(intValStr);
-				} catch (NumberFormatException e) {
+				}
+				catch (NumberFormatException e) {
 
 					throw new EPPDecodeException(
 							"Can't convert value to Integer: " + intValStr + e);
 				}
-			} else {
+			}
+			else {
 				throw new EPPDecodeException(
 						"Can't decode numeric value from non-existant text node");
 			}
@@ -605,7 +641,8 @@ public class EPPUtil {
 			// Element has text?
 			if (currVal != null) {
 				retVal.add(currVal.getNodeValue());
-			} else { // No text in element.
+			}
+			else { // No text in element.
 				retVal.add("");
 			}
 		}
@@ -646,7 +683,8 @@ public class EPPUtil {
 			// Element does have a text node?
 			if (textNode != null) {
 				retVal = textNode.getNodeValue();
-			} else {
+			}
+			else {
 				retVal = "";
 			}
 		}
@@ -672,7 +710,8 @@ public class EPPUtil {
 		// Element does have a text node?
 		if (textNode != null) {
 			retVal = textNode.getNodeValue();
-		} else {
+		}
+		else {
 			retVal = "";
 		}
 
@@ -730,8 +769,10 @@ public class EPPUtil {
 
 		try {
 			theDate = DatatypeConverter.parseDateTime(aTimeInstant).getTime();
-		} catch (IllegalArgumentException ex) {
-			cat.error("Exception decoding dateTime \"" + aTimeInstant + "\": " + ex);
+		}
+		catch (IllegalArgumentException ex) {
+			cat.error("Exception decoding dateTime \"" + aTimeInstant + "\": "
+					+ ex);
 			theDate = null;
 		}
 
@@ -777,7 +818,8 @@ public class EPPUtil {
 			// Element has text?
 			if (currVal != null) {
 				retVal.addElement(currVal.getNodeValue());
-			} else { // No text in element.
+			}
+			else { // No text in element.
 				retVal.addElement("");
 			}
 		}
@@ -894,7 +936,8 @@ public class EPPUtil {
 
 			if (aBoolean.booleanValue()) {
 				xmlValue = "1";
-			} else {
+			}
+			else {
 				xmlValue = "0";
 			}
 
@@ -921,7 +964,8 @@ public class EPPUtil {
 			boolean aVal) {
 		if (aVal) {
 			aElement.setAttribute(aAttr, "1");
-		} else {
+		}
+		else {
 			aElement.setAttribute(aAttr, "0");
 		}
 	}
@@ -1334,7 +1378,8 @@ public class EPPUtil {
 			}
 
 			return true;
-		} else {
+		}
+		else {
 			return false;
 		}
 	} // End EPPUtil.equalLists(List, List)
@@ -1375,7 +1420,8 @@ public class EPPUtil {
 			}
 
 			return true;
-		} else {
+		}
+		else {
 			return false;
 		}
 	} // End EPPUtil.equalVectors(Vector, Vector)
@@ -1618,7 +1664,8 @@ public class EPPUtil {
 			Element elm = aComponent.encode(document);
 
 			ret = toString(elm);
-		} catch (Exception ex) {
+		}
+		catch (Exception ex) {
 			ex.printStackTrace();
 		}
 
@@ -1649,7 +1696,8 @@ public class EPPUtil {
 					new StreamResult(theBuffer));
 			theBuffer.close();
 			ret = new String(theBuffer.toByteArray());
-		} catch (Exception ex) {
+		}
+		catch (Exception ex) {
 			ex.printStackTrace();
 		}
 
@@ -1678,7 +1726,8 @@ public class EPPUtil {
 					new StreamResult(theBuffer));
 			theBuffer.close();
 			ret = new String(theBuffer.toByteArray());
-		} catch (Exception ex) {
+		}
+		catch (Exception ex) {
 			ex.printStackTrace();
 		}
 
@@ -1757,13 +1806,15 @@ public class EPPUtil {
 				String intValStr = textNode.getNodeValue();
 				try {
 					retInteger = Integer.valueOf(intValStr);
-				} catch (NumberFormatException e) {
+				}
+				catch (NumberFormatException e) {
 
 					throw new EPPDecodeException(
 							"EPPUtil.decodeIntegerList Can't convert value to Integer: "
 									+ intValStr + e);
 				}
-			} else {
+			}
+			else {
 				throw new EPPDecodeException(
 						"EPPUtil.decodeIntegerList Can't decode numeric value from non-existant text node");
 			}
@@ -1845,7 +1896,8 @@ public class EPPUtil {
 			if (Character.isWhitespace(c) == false) {
 				sb.append(c); // maintain all non-whitespace characters
 				prevWhitespace = false;
-			} else {
+			}
+			else {
 				if (prevWhitespace == false) {
 					sb.append(' '); // replace each sequence of whitespace with
 					// a single space
@@ -1856,7 +1908,8 @@ public class EPPUtil {
 
 		if (sb.length() == 0) {
 			return null; // return null string when result is empty
-		} else {
+		}
+		else {
 			return sb.toString(); // return collapsed string
 		}
 
@@ -1888,7 +1941,8 @@ public class EPPUtil {
 
 		if (sb.length() == 0) {
 			return null; // return null string when result is empty
-		} else {
+		}
+		else {
 			return sb.toString(); // return result string
 		}
 
